# kkssh

Kkssh is a user-friendly SSH client that simplifies the process of connecting to remote servers. With a built-in hostname prompt, you no longer need to memorize or search for the correct hostname.

## Install

```bash
pip install kkssh --upgrade
```

## Update

```bash
python setup.py sdist
twine upload dist/*
```